@@ -5,7 +5,8 @@ import asyncio
 from lunar.config import Config
 from lunar.lunar_client import LunarClient
 
-LUNAR_DATA_API_URL = "/v1/data"
+LUNAR_DATA_DATA_API_URL = "/v1/data"
+LUNAR_DATA_BATCH_DATA_API_URL = "/v1/data/batch"
 
 loop = asyncio.get_event_loop()
 
@@ -26,7 +27,77 @@ class DataClient(LunarClient):
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = LUNAR_DATA_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_DATA_API_URL}"
+        self.api_url = (
+            LUNAR_DATA_DATA_API_URL
+            if config.ENV == "LOCAL" or config.RUNTIME_ENV == "BAP"
+            else f"/api{LUNAR_DATA_DATA_API_URL}"
+        )
+        self.batch_api_url = (
+            LUNAR_DATA_BATCH_DATA_API_URL
+            if config.ENV == "LOCAL" or config.RUNTIME_ENV == "BAP"
+            else f"/api{LUNAR_DATA_BATCH_DATA_API_URL}"
+        )
+
+    async def get_batch_data_async(
+        self, dataset_id: str, ids: List[str], attributes: List[str] = None, headers: Dict[str, Any] = dict()
+    ) -> Dict[str, Any]:
+        """
+        Get batch data results (async).
+
+        ## Args
+
+        - dataset_id: (str) Unique identifier of a dataset
+        - ids: (list) List of unique identifiers of targets
+        - attributes: (optional) (dict) Attributes to get from datasets. If not, all attributes of result would be returned
+        - headers: (optional) (dict) Headers being sent to API server
+
+        ## Returns
+        dict
+
+        ## Example
+
+        ```python
+        data = await client.get_batch_data_async(dataset_id="my_dataset", ids=["id_1", "id_2"], attributes=["f1", "f2"])
+        ```
+        """
+        assert type(ids) == list, "`ids` type must be list"
+        if attributes:
+            assert type(attributes) == list, "`attributes` type must be list"
+
+        data = {"dataset_id": dataset_id, "ids": ids}
+        if attributes:
+            data["f"] = attributes
+
+        body = await self._request(method="POST", url=self.batch_api_url, data=data, headers=headers)
+
+        return body["data"]
+
+    def get_batch_data(
+        self, dataset_id: str, ids: List[str], attributes: List[str] = None, headers: Dict[str, Any] = dict()
+    ) -> Dict[str, Any]:
+        """
+        Get batch data results.
+
+        ## Args
+
+        - dataset_id: (str) Unique identifier of a dataset
+        - ids: (list) List of unique identifiers of targets
+        - attributes: (optional) (dict) Attributes to get from datasets. If not, all attributes of result would be returned
+        - headers: (optional) (dict) Headers being sent to API server
+
+        ## Returns
+        dict
+
+        ## Example
+
+        ```python
+        data = client.get_batch_data(dataset_id="my_dataset", ids=["id_1", "id_2"], attributes=["f1", "f2"])
+        ```
+        """
+
+        return loop.run_until_complete(
+            self.get_batch_data_async(dataset_id=dataset_id, ids=ids, attributes=attributes, headers=headers)
+        )
 
     async def get_data_async(
         self, dataset_id: str, id: str, attributes: List[str] = None, headers: Dict[str, Any] = dict()
@@ -38,7 +109,7 @@ class DataClient(LunarClient):
 
         - dataset_id: (str) Unique identifier of a dataset
         - id: (str) Unique identifier of a target
-        - attributes: (optional) (dict) Attributes to get from datasets
+        - attributes: (optional) (dict) Attributes to get from datasets. If not, all attributes of result would be returned
         - headers: (optional) (dict) Headers being sent to API server
 
         ## Returns
